@@ -135,7 +135,7 @@ class VariableClBuilderAvailableDev(Variable):
 
     def get(self):
         if self.Get('os_root_type_ext') in RootType.Live:
-            return [path.join(Dracut.Workspace, "var/calculate/builder")]
+            return [path.join(Dracut.Initramfs, "builder")]
         return []
 
 
